searchNodes=[{"ref":"ContentSecurityPolicy.html","title":"ContentSecurityPolicy","type":"module","doc":"Provides functions for interacting with Content Security Policies. A Content Security Policy is a header which determines which assets the browser is allowed to retrieve. See https://developer.mozilla.org/en-US/docs/Web/HTTP/CSP for more in depth documentation."},{"ref":"ContentSecurityPolicy.html#add_source_value/3","title":"ContentSecurityPolicy.add_source_value/3","type":"function","doc":"Adds a single source value to a directive on the given policy."},{"ref":"ContentSecurityPolicy.html#generate_nonce/1","title":"ContentSecurityPolicy.generate_nonce/1","type":"function","doc":"Generates a random base 64 encoded string for use in Content Security Policy nonces."},{"ref":"ContentSecurityPolicy.html#serialize/1","title":"ContentSecurityPolicy.serialize/1","type":"function","doc":"Converts a ContentSecurityPolicy.Policy struct to a valid content security policy string. Examples iex&gt; policy = %ContentSecurityPolicy.Policy{default_src: [&quot;&#39;self&#39;&quot;]} iex&gt; ContentSecurityPolicy.serialize(policy) &quot;default-src &#39;self&#39;;&quot;"},{"ref":"ContentSecurityPolicy.Directive.html","title":"ContentSecurityPolicy.Directive","type":"module","doc":"Contains functions useful for interacting with Content Security Policy directives. Directives are the keys in a content secrurity which define the scope of what the source values apply to. As an example, in the policy of &quot;default-src &#39;self&#39;&quot;, default-src is the directive."},{"ref":"ContentSecurityPolicy.Directive.html#validate_directive!/1","title":"ContentSecurityPolicy.Directive.validate_directive!/1","type":"function","doc":"Validates a given directive. Used by other functions in ContentSecurityPolicy. Raises an ArgumentError if the directive is not valid."},{"ref":"ContentSecurityPolicy.Directive.html#t:valid_directive/0","title":"ContentSecurityPolicy.Directive.valid_directive/0","type":"opaque","doc":""},{"ref":"ContentSecurityPolicy.Plug.AddNonce.html","title":"ContentSecurityPolicy.Plug.AddNonce","type":"module","doc":"Plug which adds a random nonce to the content security policy. Sets this nonce in Plug.assigns under the csp_nonce key. This plug must be run after the ContentSecurityPolicy.Setup plug, or it will raise an exception. Example Usage In a controller or router: plug ContentSecurityPolicy.Plug.Setup plug ContentSecurityPolicy.Plug.AddNonce, directives: [:script_src] The nonce is then added to the script-src directive and will be sent in the &quot;content-security-policy&quot; response header. To access this nonce value when rendering a response, check conn.assigns[:csp_nonce]. conn.assigns[:csp_nonce] &quot;EDNnf03nceIOfn39fn3e9h3sdfa&quot; If using .eex templates to render a response, that might look something like: &lt;script nonce=&quot;&lt;%= @conn.assigns[:csp_nonce] %&gt;&quot;&gt; ... #JavaScript I&#39;d like to be allowed &lt;/script&gt; When the response is sent to the browser, the &quot;content-security-policy&quot; response header will contain &quot;script-src &#39;nonce-EDNnf03nceIOfn39fn3e9h3sdfa&#39;&quot;, which should cause the browser to whitelist this specific script. Note that the nonce is randomly generated for every single request, which ensures that an attacker can&#39;t just guess your nonce and get their malicious script/resource run."},{"ref":"ContentSecurityPolicy.Plug.AddNonce.html#call/2","title":"ContentSecurityPolicy.Plug.AddNonce.call/2","type":"function","doc":""},{"ref":"ContentSecurityPolicy.Plug.AddNonce.html#init/1","title":"ContentSecurityPolicy.Plug.AddNonce.init/1","type":"function","doc":""},{"ref":"ContentSecurityPolicy.Plug.AddSourceValue.html","title":"ContentSecurityPolicy.Plug.AddSourceValue","type":"module","doc":"Plug which adds a source value to the given directive. This plug must be run after the ContentSecurityPolicy.Setup plug, or it will raise an exception. Example Usage In a controller or router: plug ContentSecurityPolicy.Setup plug ContentSecurityPolicy.AddSourceValue, script_src: &quot;https://google.com&quot; When the response is sent to the browser, the &quot;content-security-policy&quot; response header will contain &quot;script-src https://google.com&quot; directive. Multiple directives and source values can be provided in the same call. plug ContentSecurityPolicy.AddSourceValue, script_src: &quot;&#39;self&#39;&quot;, script_src: &quot;https://google.com&quot; When the response is sent to the browser, the &quot;content-security-policy&quot; response header will contain &quot;script-src &#39;self&#39; https://google.com&quot; directive. The ContentSecurityPolicy.Plug.AddSourceValue plug is additive. It will never replace or remove old source values associated with a directive."},{"ref":"ContentSecurityPolicy.Plug.AddSourceValue.html#call/2","title":"ContentSecurityPolicy.Plug.AddSourceValue.call/2","type":"function","doc":""},{"ref":"ContentSecurityPolicy.Plug.AddSourceValue.html#init/1","title":"ContentSecurityPolicy.Plug.AddSourceValue.init/1","type":"function","doc":""},{"ref":"ContentSecurityPolicy.Plug.Setup.html","title":"ContentSecurityPolicy.Plug.Setup","type":"module","doc":"Plug that sets the default policy and ensures that the proper &quot;content-security-policy&quot; header is set before the response is sent. This Plug registers a before_send action that serializes the ContentSecurityPolicy.Policy struct and inserts the result into the &quot;content-security-policy&quot; header of the response. Example Usage In a controller or router: plug ContentSecurityPolicy.Plug.Setup( default_policy: %ContentSecurityPolicy.Policy{ default_src: [&quot;https:&quot;, &quot;&#39;self&#39;&quot;], img_src: [&quot;*.imgur.com&quot;] } ) The above plug sets the content security policy struct to whatever is passed in. This is assigned to conn.private.content_security_policy. Before the response is sent, this policy will be serialized into a content security policy that the browser understands. In the case of the above, the following response header will be sent: content-security-policy: default-src https: &#39;self&#39;; img-src *.imgur.com"},{"ref":"ContentSecurityPolicy.Plug.Setup.html#call/2","title":"ContentSecurityPolicy.Plug.Setup.call/2","type":"function","doc":""},{"ref":"ContentSecurityPolicy.Plug.Setup.html#init/1","title":"ContentSecurityPolicy.Plug.Setup.init/1","type":"function","doc":""},{"ref":"ContentSecurityPolicy.Policy.html","title":"ContentSecurityPolicy.Policy","type":"module","doc":"Defines the ContentSecurityPolicy.Policy struct which represents a given Content Security Policy. This struct is intended to be a programattic representation of a policy which will need to be serialized to a valid content security policy before the browser can understand it."},{"ref":"ContentSecurityPolicy.Policy.html#t:t/0","title":"ContentSecurityPolicy.Policy.t/0","type":"type","doc":""},{"ref":"getting-started.html","title":"Getting Started","type":"extras","doc":"Getting Started"},{"ref":"getting-started.html#description","title":"Getting Started - Description","type":"extras","doc":"ContentSecurityPolicy makes working with the &quot;Content-Security-Policy&quot; response header simple. The &quot;Content-Security-Policy&quot; header is a header that restricts how a browser can receive resources such as images and scripts. It&#39;s intent is to improve security by making it more difficult for an attacker to get the browser to run an arbitrary thing."},{"ref":"getting-started.html#installation","title":"Getting Started - Installation","type":"extras","doc":"The package can be installed by adding content_security_policy to your list of dependencies in mix.exs: def deps do [ {:content_security_policy, &quot;~&gt; 1.0&quot;} ] end"},{"ref":"getting-started.html#why-use-this","title":"Getting Started - Why use this?","type":"extras","doc":"Using a &quot;Content-Security-Policy&quot; header is a great way to improve the security of a web application that serves HTML to a browser. It allows the specification of exactly which resources are allowed to be loaded and how. The &quot;Content-Security-Policy&quot; header can specify, for example, that only scripts from either the application&#39;s server or google.com which are retrieved using https should be allowed. If an attacker were somehow able to inject a script and get it to run, the browser would consult the &quot;Content-Security-Policy&quot; header and then deny that script from running. This makes it much harder for Cross-Site Scripting (XSS) attacks to succeed. If you&#39;ve used sobelow, with a default Phoenix project, you may have noticed a warning telling you something about a Content Security Policy. This project aims to make it extremely easy to deal with that warning. Another strength of this project is that it makes dealing with Content Security Policy nonces simple. Nonces are a way of telling the browser that a specific resource is okay when the server might otherwise not know how to describe that resource via CSP. A good example of this is a dynamically generated QR Code. Although it&#39;s possible to calculate the SHA hash of the QR code, it&#39;s often easier to use a nonce and call it a day. For more on this use case check out the documentation in the ContentSecurityPolicy.Plug.AddNonce plug."},{"ref":"getting-started.html#content-security-policy-terminology","title":"Getting Started - Content Security Policy Terminology","type":"extras","doc":"There are many functions and modules which reference terminology of Content Security Policies. It&#39;s probably a good idea to define this terminology, so here goes. Let&#39;s take an example content security policy header: content-security-policy: default-src https: &#39;self&#39;; img-src https://imgur.com; That whole thing is known as the Content Security Policy Response Header. The contents of that (default-src https: &#39;self&#39;; img-src https://imgur.com;) are referred to as the Content Security Policy or simply Policy. That policy contains two Directives (default-src and img-src). Each Directive contains a number of Source Values. The default-src directive contains the https: and &#39;self&#39; source values. The img-src directive contains the https://imgur.com source value."},{"ref":"getting-started.html#how-does-it-work","title":"Getting Started - How does it work?","type":"extras","doc":"If we just want to set one Content Security Policy we can just add the following plug to our Router (in the appropriate pipeline or place, of course). plug ContentSecurityPolicy.Plug.Setup( default_policy: %ContentSecurityPolicy.Policy{ default_src: [&quot;https:&quot;, &quot;&#39;self&#39;&quot;], img_src: [&quot;https://imgur.com&quot;] } ) The above plug sets the content security policy struct to whatever is passed in. This is assigned to conn.private.content_security_policy. It also sets up a before_send action which serializes that value to a string that the browser understands and stuffs it into the &quot;content-security-policy&quot; header right before the response is sent. This means we can modify the content security policy in conn.private.content_security_policy all we want and it&#39;ll only ever be serialized once. Adding a Source Value to a Directive If a specific page has a resource that other pages do not, it is possible to add that specific source value to a directive for that controller function only. This means that you can get a bit more granular than simply setting a global content security policy that references resources that are only retrieved in very specific isntances. For more on this see the ContentSecurityPolicy.Plug.AddSourceValue module documentation. Nonces The ContentSecurityPolicy.Plug.AddNonce plug makes working with nonces easy. For more on this functionality, check out the module documentation in ContentSecurityPolicy.Plug.AddNonce. Accessing Lower Level Functionality The ContentSecurityPolicy module contains all of the functions you might need if you want to interact with Content Security Policies at a lower level. The plugs provided with this project should make this unnecessary... but if you need this, it&#39;s there!"}]